@@ -1,8 +1,8 @@
-/** 
+/**
  * @file gnome-cmd-file-props-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2020 Uwe Scholz\n
+ * @copyright (C) 2013-2022 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
  */
 
 #include <config.h>
-#include <libgnomevfs/gnome-vfs-mime-monitor.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir.h"
@@ -44,7 +43,6 @@ struct GnomeCmdFilePropsDialogPrivate
     GtkWidget *dialog;
     GnomeCmdFile *f;
     GThread *thread;
-    GMutex mutex;
     gboolean count_done;
     gchar *msg;
     guint updater_proc_id;
@@ -54,8 +52,8 @@ struct GnomeCmdFilePropsDialogPrivate
 
     // Properties tab stuff
     gboolean stop;
-    GnomeVFSFileSize size;
-    GnomeVFSURI *uri;
+    guint64 size;
+    GFile *gFile;
     GtkWidget *filename_entry;
     GtkWidget *size_label;
     GtkWidget *app_label;
@@ -67,67 +65,6 @@ struct GnomeCmdFilePropsDialogPrivate
 };
 
 
-static void calc_tree_size_r (GnomeCmdFilePropsDialogPrivate *data, GnomeVFSURI *uri)
-{
-    GList *list = NULL;
-    gchar *uri_str;
-
-    if (data->stop)
-        g_thread_exit (NULL);
-
-    if (!uri) return;
-    uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_PASSWORD);
-    if (!uri_str) return;
-
-    GnomeVFSResult result = gnome_vfs_directory_list_load (&list, uri_str, GNOME_VFS_FILE_INFO_DEFAULT);
-
-    if (result != GNOME_VFS_OK) return;
-    if (!list) return;
-
-    for (GList *i = list; i; i = i->next)
-    {
-        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) i->data;
-
-        if (strcmp (info->name, ".") != 0 && strcmp (info->name, "..") != 0)
-        {
-            if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
-            {
-                GnomeVFSURI *new_uri = gnome_vfs_uri_append_file_name (uri, info->name);
-                calc_tree_size_r (data, new_uri);
-                gnome_vfs_uri_unref (new_uri);
-            }
-            else
-                data->size += info->size;
-        }
-    }
-
-    for (GList *i = list; i; i = i->next)
-    {
-        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) i->data;
-        gnome_vfs_file_info_unref (info);
-    }
-
-    g_list_free (list);
-    g_free (uri_str);
-
-    if (data->stop)
-        g_thread_exit (NULL);
-
-    g_mutex_lock (&data->mutex);
-    g_free (data->msg);
-    data->msg = create_nice_size_str (data->size);
-    g_mutex_unlock (&data->mutex);
-}
-
-
-static void calc_tree_size_func (GnomeCmdFilePropsDialogPrivate *data)
-{
-    calc_tree_size_r (data, data->uri);
-
-    data->count_done = TRUE;
-}
-
-
 // Tells the thread to exit and then waits for it to do so.
 static gboolean join_thread_func (GnomeCmdFilePropsDialogPrivate *data)
 {
@@ -153,10 +90,11 @@ static void on_dialog_destroy (GtkDialog *dialog, GnomeCmdFilePropsDialogPrivate
 
 static gboolean update_count_status (GnomeCmdFilePropsDialogPrivate *data)
 {
-    g_mutex_lock (&data->mutex);
-    if (data->size_label)
+    if (data->size_label && data->size != 0)
+    {
+        data->msg = create_nice_size_str (data->size);
         gtk_label_set_text (GTK_LABEL (data->size_label), data->msg);
-    g_mutex_unlock (&data->mutex);
+    }
 
     if (data->count_done)
     {
@@ -168,15 +106,57 @@ static gboolean update_count_status (GnomeCmdFilePropsDialogPrivate *data)
 }
 
 
+static void g_file_measure_disk_usage_async_callback(GObject *unused, GAsyncResult *result, gpointer user_data)
+{
+    g_return_if_fail (user_data != nullptr);
+
+    auto data = (GnomeCmdFilePropsDialogPrivate *) user_data;
+    GError *error = nullptr;
+
+    g_file_measure_disk_usage_finish (data->gFile, result, &(data->size), nullptr, nullptr, &error);
+
+    if(error)
+    {
+        g_message("g_file_measure_disk_usage_finish error: %s\n", error->message);
+        g_error_free(error);
+        data->count_done = TRUE;
+        return;
+    }
+
+    data->msg = create_nice_size_str (data->size);
+
+    data->count_done = TRUE;
+}
+
+
+static void progress_callback (gboolean reporting,
+                                 guint64 current_size,
+                                 guint64 num_dirs,
+                                 guint64 num_files,
+                                 gpointer user_data)
+{
+    auto data = (GnomeCmdFilePropsDialogPrivate *) user_data;
+
+    data->size = current_size;
+}
+
+
 static void do_calc_tree_size (GnomeCmdFilePropsDialogPrivate *data)
 {
-    g_return_if_fail (data != NULL);
+    g_return_if_fail (data != nullptr);
 
     data->stop = FALSE;
     data->size = 0;
     data->count_done = FALSE;
 
-    data->thread = g_thread_new (NULL, (PthreadFunc) calc_tree_size_func, data);
+    g_file_measure_disk_usage_async (data->gFile,
+                                 G_FILE_MEASURE_NONE,
+                                 G_PRIORITY_LOW,
+                                 nullptr, // ToDo: maybe change this cancalable thing later
+                                 progress_callback,
+                                 data,
+                                 g_file_measure_disk_usage_async_callback,
+                                 data);
 
     data->updater_proc_id = g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_count_status, data);
 }
@@ -187,39 +167,45 @@ static void do_calc_tree_size (GnomeCmdFilePropsDialogPrivate *data)
 
 static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
 {
-    GnomeVFSResult result = GNOME_VFS_OK;
+    GError *error;
+    error = nullptr;
+
+    gboolean retValue = true;
 
     const gchar *filename = gtk_entry_get_text (GTK_ENTRY (data->filename_entry));
 
     if (strcmp (filename, data->f->get_name()) != 0)
     {
-        result = data->f->rename(filename);
+        retValue = data->f->rename(filename, &error);
 
-        if (result==GNOME_VFS_OK)
+        if (retValue)
             main_win->fs(ACTIVE)->file_list()->focus_file(filename, TRUE);
     }
 
-    if (result == GNOME_VFS_OK)
+    if (retValue)
     {
-        GnomeVFSFilePermissions perms = gnome_cmd_chmod_component_get_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component));
+        auto perms = gnome_cmd_chmod_component_get_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component));
 
-        if (perms != data->f->info->permissions)
-            result = data->f->chmod(perms);
+        if (perms != (get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_MODE) & 0xFFF ))
+            retValue = data->f->chmod(perms, &error);
     }
 
-    if (result == GNOME_VFS_OK)
+    if (retValue)
     {
-        
         uid_t uid = gnome_cmd_chown_component_get_owner (GNOME_CMD_CHOWN_COMPONENT (data->chown_component));
         gid_t gid = gnome_cmd_chown_component_get_group (GNOME_CMD_CHOWN_COMPONENT (data->chown_component));
 
-        if (uid != data->f->info->uid || gid != data->f->info->gid)
-            result = data->f->chown(uid,gid);
+        if (   uid != get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_UID)
+            || gid != get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_GID))
+        {
+            retValue = data->f->chown(uid, gid, &error);
+        }
     }
 
-    if (result != GNOME_VFS_OK)
+    if (!retValue && error != nullptr)
     {
-        gnome_cmd_show_message (NULL, filename, gnome_vfs_result_to_string (result));
+        gnome_cmd_show_message (nullptr, filename, error->message);
+        g_error_free(error);
         return;
     }
 
@@ -235,7 +221,7 @@ static void on_dialog_cancel (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *da
 
 static void on_copy_clipboard (GtkButton *button, GnomeCmdFilePropsDialogPrivate *data)
 {
-    g_return_if_fail (data != NULL);
+    g_return_if_fail (data != nullptr);
 
     string s;
 
@@ -286,7 +272,7 @@ inline void add_sep (GtkWidget *table, gint y)
 }
 
 
-static void add_tag (GtkWidget *dialog, GtkWidget *table, gint &y, GnomeCmdFileMetadata &metadata, GnomeCmdTag tag, const gchar *appended_text=NULL)
+static void add_tag (GtkWidget *dialog, GtkWidget *table, gint &y, GnomeCmdFileMetadata &metadata, GnomeCmdTag tag, const gchar *appended_text=nullptr)
 {
     if (!metadata.has_tag (tag))
         return;
@@ -334,7 +320,6 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     GtkWidget *dialog = data->dialog;
     GtkWidget *table;
     GtkWidget *label;
-    gchar *fname;
 
     GtkWidget *space_frame = create_space_frame (dialog, 6);
 
@@ -344,18 +329,16 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_bold_label (dialog, GNOME_CMD_IS_DIR (data->f) ? _("Directory name:") : _("File name:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    fname = get_utf8 (data->f->get_name());
-    data->filename_entry = create_entry (dialog, "filename_entry", fname);
-    g_free (fname);
+    data->filename_entry = create_entry (dialog, "filename_entry", g_file_info_get_edit_name (data->f->gFileInfo));
     table_add (table, data->filename_entry, 1, y++, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND));
     gtk_editable_set_position (GTK_EDITABLE (data->filename_entry), 0);
 
-    if (data->f->info->symlink_name)
+    if (g_file_info_get_is_symlink(data->f->gFileInfo))
     {
         label = create_bold_label (dialog, _("Symlink target:"));
         table_add (table, label, 0, y, GTK_FILL);
 
-        label = create_label (dialog, data->f->info->symlink_name);
+        label = create_label (dialog, g_file_info_get_symlink_target (data->f->gFileInfo));
         table_add (table, label, 1, y++, GTK_FILL);
     }
 
@@ -364,7 +347,7 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     if (data->f->is_local())
     {
         GnomeCmdDir *dir = data->f->get_parent_dir();
-        GnomeCmdCon *con = dir ? gnome_cmd_dir_get_connection (dir) : NULL;
+        GnomeCmdCon *con = dir ? gnome_cmd_dir_get_connection (dir) : nullptr;
         gchar *location = GNOME_CMD_FILE (dir)->get_real_path();
 
         label = create_bold_label (dialog, _("Location:"));
@@ -380,15 +363,13 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
 
         if (GNOME_CMD_IS_CON_DEVICE (con))
         {
-            if (GnomeVFSVolume *vol = gnome_cmd_con_device_get_vfs_volume (GNOME_CMD_CON_DEVICE (con)))
+            if (auto *gMount = gnome_cmd_con_device_get_gmount (GNOME_CMD_CON_DEVICE (con)))
             {
-                gchar *fs_type = gnome_vfs_volume_get_filesystem_type (vol);
-                gchar *dev_path = gnome_vfs_volume_get_device_path (vol);
+                gchar *dev_uuid = g_mount_get_uuid (gMount);
 
-                gchar *s = g_strdup_printf ("%s (%s, %s)", gnome_cmd_con_get_alias (con), dev_path, fs_type);
+                gchar *s = g_strdup_printf ("%s (%s)", gnome_cmd_con_get_alias (con), dev_uuid);
 
-                g_free (fs_type);
-                g_free (dev_path);
+                g_free (dev_uuid);
 
                 label = create_label (dialog, s);
 
@@ -417,33 +398,27 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
         add_sep (table, y++);
     }
 
-    label = create_bold_label (dialog, _("Type:"));
+    label = create_bold_label (dialog, _("Content Type:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, data->f->get_mime_type_desc());
+    auto contentTypeString = data->f->GetGfileAttributeString(G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
+    label = create_label (dialog, contentTypeString);
     table_add (table, label, 1, y++, GTK_FILL);
+    g_free(contentTypeString);
 
-
-    label = create_bold_label (dialog, _("MIME Type:"));
-    table_add (table, label, 0, y, GTK_FILL);
-
-    label = create_label (dialog, data->f->get_mime_type());
-    table_add (table, label, 1, y++, GTK_FILL);
-
-
-    if (data->f->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
+    if (data->f->GetGfileAttributeUInt32(G_FILE_ATTRIBUTE_STANDARD_TYPE) != G_FILE_TYPE_DIRECTORY)
     {
         GtkWidget *hbox;
 
         label = create_bold_label (dialog, _("Opens with:"));
         table_add (table, label, 0, y, GTK_FILL);
 
-        GnomeVFSMimeApplication *vfs_app = data->f->get_default_application();
+        auto default_application_string = data->f->GetDefaultApplicationNameString();
 
-        if (vfs_app)
+        if (default_application_string)
         {
-            data->app_label = label = create_label (dialog, vfs_app->name);
-            gnome_vfs_mime_application_free (vfs_app);
+            data->app_label = label = create_label (dialog, default_application_string);
+            g_free (default_application_string);
         }
         else
             label = create_label (dialog, _("No default application registered"));
@@ -463,12 +438,13 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_label (dialog, data->f->get_mdate(TRUE));
     table_add (table, label, 1, y++, GTK_FILL);
 
+#ifdef GLIB_2_70
     label = create_bold_label (dialog, _("Accessed:"));
     table_add (table, label, 0, y, GTK_FILL);
 
     label = create_label (dialog, data->f->get_adate(TRUE));
     table_add (table, label, 1, y++, GTK_FILL);
-
+#endif
 
     add_sep (table, y++);
 
@@ -476,16 +452,16 @@ static GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_bold_label (dialog, _("Size:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    gchar *s = create_nice_size_str (data->f->info->size);
+    gchar *s = create_nice_size_str (g_file_info_get_size (data->f->gFileInfo));
     label = create_label (dialog, s);
     table_add (table, label, 1, y++, GTK_FILL);
     g_free (s);
-    if (data->f->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+    if (data->f->GetGfileAttributeUInt32(G_FILE_ATTRIBUTE_STANDARD_TYPE) == G_FILE_TYPE_DIRECTORY)
         do_calc_tree_size (data);
 
     data->size_label = label;
 
-    if (data->f->info->type != GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE) 
+    if (data->f->GetGfileAttributeUInt32(G_FILE_ATTRIBUTE_STANDARD_TYPE) != G_FILE_TYPE_SPECIAL)
         gcmd_tags_bulk_load (data->f);
 
     if (data->f->metadata)
@@ -517,17 +493,19 @@ inline GtkWidget *create_permissions_tab (GnomeCmdFilePropsDialogPrivate *data)
     g_object_set_data_full (G_OBJECT (data->dialog), "chown_component", data->chown_component, g_object_unref);
     gtk_widget_show (data->chown_component);
     gnome_cmd_chown_component_set (GNOME_CMD_CHOWN_COMPONENT (data->chown_component),
-        data->f->info->uid, data->f->info->gid);
+        get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_UID),
+        get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_GID));
 
     GtkWidget *cat = create_category (data->dialog, data->chown_component, _("Owner and group"));
     gtk_box_pack_start (GTK_BOX (vbox), cat, TRUE, TRUE, 0);
 
 
-    data->chmod_component = gnome_cmd_chmod_component_new ((GnomeVFSFilePermissions) 0);
+    data->chmod_component = gnome_cmd_chmod_component_new (0);
     g_object_ref (data->chmod_component);
     g_object_set_data_full (G_OBJECT (data->dialog), "chmod_component", data->chmod_component, g_object_unref);
     gtk_widget_show (data->chmod_component);
-    gnome_cmd_chmod_component_set_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component), data->f->info->permissions);
+    gnome_cmd_chmod_component_set_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component),
+        get_gfile_attribute_uint32(data->f->gFile, G_FILE_ATTRIBUTE_UNIX_MODE) & 0xFFF);
 
     cat = create_category (data->dialog, data->chmod_component, _("Access permissions"));
     gtk_box_pack_start (GTK_BOX (vbox), cat, TRUE, TRUE, 0);
@@ -556,7 +534,7 @@ static GtkTreeModel *create_and_fill_model (GnomeCmdFile *f)
                                                   G_TYPE_STRING,
                                                   G_TYPE_STRING);
 
-    if (f->info->type == GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE || !gcmd_tags_bulk_load (f))
+    if (f->GetGfileAttributeUInt32(G_FILE_ATTRIBUTE_STANDARD_TYPE) == G_FILE_TYPE_SPECIAL || !gcmd_tags_bulk_load (f))
         return GTK_TREE_MODEL (treestore);
 
     GnomeCmdTagClass prev_tagclass = TAG_NONE_CLASS;
@@ -573,7 +551,7 @@ static GtkTreeModel *create_and_fill_model (GnomeCmdFile *f)
 
         if (prev_tagclass!=curr_tagclass)
         {
-            gtk_tree_store_append (treestore, &toplevel, NULL);
+            gtk_tree_store_append (treestore, &toplevel, nullptr);
             gtk_tree_store_set (treestore, &toplevel,
                                 COL_TAG, TAG_NONE,
                                 COL_TYPE, gcmd_tags_get_class_name(t),
@@ -608,10 +586,10 @@ static GtkWidget *create_view_and_model (GnomeCmdFile *f)
                   "rules-hint", TRUE,
                   "enable-search", TRUE,
                   "search-column", COL_VALUE,
-                  NULL);
+                  nullptr);
 
-    GtkCellRenderer *renderer = NULL;
-    GtkTreeViewColumn *col = NULL;
+    GtkCellRenderer *renderer = nullptr;
+    GtkTreeViewColumn *col = nullptr;
 
     col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_TYPE, _("Type"));
     gtk_widget_set_tooltip_text (col->button, _("Metadata namespace"));
@@ -619,7 +597,7 @@ static GtkWidget *create_view_and_model (GnomeCmdFile *f)
     g_object_set (renderer,
                   "weight-set", TRUE,
                   "weight", PANGO_WEIGHT_BOLD,
-                  NULL);
+                  nullptr);
 
     col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), COL_NAME, _("Name"));
     gtk_widget_set_tooltip_text (col->button, _("Tag name"));
@@ -635,7 +613,7 @@ static GtkWidget *create_view_and_model (GnomeCmdFile *f)
                   "foreground", "DarkGray",
                   "ellipsize-set", TRUE,
                   "ellipsize", PANGO_ELLIPSIZE_END,
-                  NULL);
+                  nullptr);
 
     GtkTreeModel *model = create_and_fill_model (f);
 
@@ -656,7 +634,7 @@ inline GtkWidget *create_metadata_tab (GnomeCmdFilePropsDialogPrivate *data)
     GtkWidget *space_frame = create_space_frame (data->dialog, 1);
     gtk_container_add (GTK_CONTAINER (space_frame), vbox);
 
-    GtkWidget *scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+    GtkWidget *scrolledwindow = gtk_scrolled_window_new (nullptr, nullptr);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
     gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow), 10);
 
@@ -674,11 +652,11 @@ inline GtkWidget *create_metadata_tab (GnomeCmdFilePropsDialogPrivate *data)
 
 GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f)
 {
-    g_return_val_if_fail (f != NULL, NULL);
-    g_return_val_if_fail (f->info != NULL, NULL);
+    g_return_val_if_fail (f != nullptr, nullptr);
+    g_return_val_if_fail (f->gFileInfo != nullptr, nullptr);
 
     if (f->is_dotdot)
-        return NULL;
+        return nullptr;
 
     GnomeCmdFilePropsDialogPrivate *data = g_new0 (GnomeCmdFilePropsDialogPrivate, 1);
     // data->thread = 0;
@@ -691,9 +669,8 @@ GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f)
 
     data->dialog = GTK_WIDGET (dialog);
     data->f = f;
-    data->uri = f->get_uri();
-    g_mutex_init(&data->mutex);
-    data->msg = NULL;
+    data->gFile = f->get_gfile();
+    data->msg = nullptr;
     data->notebook = notebook;
     f->ref();
 
