@@ -2,7 +2,7 @@
  * @file gnome-cmd-remote-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2020 Uwe Scholz\n
+ * @copyright (C) 2013-2022 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "gnome-cmd-remote-dialog.h"
 #include "gnome-cmd-con-list.h"
 #include "gnome-cmd-data.h"
+#include "gnome-cmd-con-smb.h"
 #include "gnome-cmd-treeview.h"
 #include "imageloader.h"
 #include "gnome-cmd-file-selector.h"
@@ -38,7 +39,6 @@ using namespace std;
 struct GnomeCmdRemoteDialog::Private
 {
     GtkWidget *connection_list;
-    GtkWidget *anonymous_pw_entry;
     GtkWidget *connect_button;
 };
 
@@ -102,15 +102,20 @@ inline void set_server (GtkListStore *store, GtkTreeIter *iter, GnomeCmdConRemot
 
     gtk_list_store_set (store, iter,
                         COL_METHOD, gnome_cmd_con_get_icon_name (con->method),
-                        COL_LOCK, con->auth==GnomeCmdCon::SAVE_PERMANENTLY ? GTK_STOCK_DIALOG_AUTHENTICATION : NULL,
-                        COL_AUTH, con->auth,
+                        COL_LOCK, nullptr,
+                        COL_AUTH, 0, // ToDo: Remove?
                         COL_NAME, gnome_cmd_con_get_alias (con),
                         COL_CON, con,
                         COL_FTP_CON, server,                // FIXME: to be removed
                         -1);
 }
 
-
+/**
+ * @brief This function connects to the given GnomeCmdConRemote server.
+ *
+ * @param server The GnomeCmdConRemote to connect to.
+ * @return FALSE for the case it is called from g_timeout_add()
+ */
 static gboolean do_connect_real (GnomeCmdConRemote *server)
 {
     GnomeCmdCon *con = GNOME_CMD_CON (server);
@@ -133,10 +138,6 @@ inline void GnomeCmdRemoteDialog::do_connect(GnomeCmdConRemote *server)
     if (!server)        // exit as there is no server selected
         return;
 
-    // store the anonymous ftp password as the user might have changed it
-    const gchar *anon_pw = gtk_entry_get_text (GTK_ENTRY (priv->anonymous_pw_entry));
-    gnome_cmd_data_set_ftp_anonymous_password (anon_pw);
-
     gtk_widget_destroy (*this);
 
     g_timeout_add (1, (GtkFunction) do_connect_real, server);
@@ -400,7 +401,7 @@ static void gnome_cmd_remote_dialog_class_init (GnomeCmdRemoteDialogClass *klass
 
 static void gnome_cmd_remote_dialog_init (GnomeCmdRemoteDialog *dialog)
 {
-    GtkWidget *cat_box, *table, *cat, *sw, *label, *button, *bbox;
+    GtkWidget *cat_box, *table, *cat, *sw, *button, *bbox;
 
     dialog->priv = g_new0 (GnomeCmdRemoteDialog::Private, 1);
 
@@ -442,12 +443,6 @@ static void gnome_cmd_remote_dialog_init (GnomeCmdRemoteDialog *dialog)
     cat = create_category (*dialog, table, _("Options"));
     gnome_cmd_dialog_add_category (*dialog, cat);
 
-    label = create_label (*dialog, _("Anonymous FTP password:"));
-    table_add (table, label, 0, 0, (GtkAttachOptions) 0);
-
-    dialog->priv->anonymous_pw_entry = create_entry (*dialog, "anonymous_pw_entry", gnome_cmd_data_get_ftp_anonymous_password ());
-    table_add (table, dialog->priv->anonymous_pw_entry, 1, 0, GTK_FILL);
-
     gnome_cmd_dialog_add_button (*dialog, GTK_STOCK_HELP, GTK_SIGNAL_FUNC (on_help_btn_clicked), dialog);
     gnome_cmd_dialog_add_button (*dialog, GTK_STOCK_CLOSE, GTK_SIGNAL_FUNC (on_close_btn_clicked), dialog);
     button = gnome_cmd_dialog_add_button (*dialog, GTK_STOCK_CONNECT, GTK_SIGNAL_FUNC (on_connect_btn_clicked), dialog);
