@@ -99,18 +99,19 @@ static void do_legacy_mount(GnomeCmdCon *con)
         gchar *cmd = nullptr;
         gchar *emsg = nullptr;
 
-        if (dev_con->priv->device_fn != nullptr && dev_con->priv->mountp != nullptr)
-        {
-            DEBUG ('m', "mounting %s\n", dev_con->priv->mountp);
-            if (dev_con->priv->device_fn)
-                cmd = g_strdup_printf ("mount %s %s", dev_con->priv->device_fn, dev_con->priv->mountp);
-            else
-                cmd = g_strdup_printf ("mount %s", dev_con->priv->mountp);
-        }
-
-        if (!cmd)
+        if (strlen(dev_con->priv->device_fn) == 0)
             return;
 
+        DEBUG ('m', "mounting %s\n", dev_con->priv->device_fn);
+        if (dev_con->priv->device_fn[0] == G_DIR_SEPARATOR)
+        {
+            cmd = g_strdup_printf ("mount %s", dev_con->priv->device_fn);
+        }
+        else
+        {
+            cmd = g_strdup_printf ("mount -L %s", dev_con->priv->device_fn);
+        }
+
         DEBUG ('m', "Mount command: %s\n", cmd);
         ret = system (cmd);
         estatus = WEXITSTATUS (ret);
@@ -158,7 +159,8 @@ static void set_con_mount_succeed(GnomeCmdCon *con)
 
 static void set_con_mount_failed(GnomeCmdCon *con)
 {
-    g_object_unref (con->base_gFileInfo);
+    if (con->base_gFileInfo)
+        g_object_unref (con->base_gFileInfo);
     con->base_gFileInfo = nullptr;
     con->open_result = GnomeCmdCon::OPEN_FAILED;
     con->state = GnomeCmdCon::STATE_CLOSED;
@@ -201,19 +203,21 @@ static void do_legacy_mount_thread_func(GnomeCmdCon *con)
     GError *error = nullptr;
 
     if (!con->base_path)
-        con->base_path = new GnomeCmdPlainPath(G_DIR_SEPARATOR_S);
+    {
+        con->base_path = new GnomeCmdPlainPath(GNOME_CMD_CON_DEVICE(con)->priv->mountp);
+    }
 
     do_legacy_mount(con);
 
-    auto gFile = gnome_cmd_con_create_gfile(con, con->base_path);
-
-    if (!gFile)
+    if (con->open_result == GnomeCmdCon::OPEN_FAILED)
     {
-        con->open_failed_error = g_error_new(G_IO_ERROR, G_IO_ERROR_FAILED, "Unable to create a GFile object for the given path.");
+        con->open_failed_error = g_error_new(G_IO_ERROR, G_IO_ERROR_FAILED, "Unable to mount %s", GNOME_CMD_CON_DEVICE (con)->priv->device_fn);
         set_con_mount_failed(con);
-        g_warning("Unable to create a GFile object for the given path.");
         return;
     }
+
+    auto gFile = gnome_cmd_con_create_gfile(con, con->base_path);
+
     con->base_gFileInfo = g_file_query_info(gFile,
                               "*",
                               G_FILE_QUERY_INFO_NONE,
@@ -248,25 +252,27 @@ static void do_mount (GnomeCmdCon *con)
     }
 
     // Check if the volume is already mounted:
-    auto gMount = g_volume_get_mount (dev_con->priv->gVolume);
-    if (gMount)
+    if (dev_con->priv->gVolume)
     {
-        dev_con->priv->gMount = gMount;
-        set_con_base_path_for_gmount(con, dev_con->priv->gMount);
-        set_con_base_gfileinfo(con);
-        set_con_mount_succeed(con);
-        return;
+        auto gMount = g_volume_get_mount (dev_con->priv->gVolume);
+        if (gMount)
+        {
+            dev_con->priv->gMount = gMount;
+            set_con_base_path_for_gmount(con, dev_con->priv->gMount);
+            set_con_base_gfileinfo(con);
+            set_con_mount_succeed(con);
+            return;
+        }
+
+        auto gMountOperation = gtk_mount_operation_new ((GtkWindow*) main_win);
+
+        g_volume_mount (dev_con->priv->gVolume,
+            G_MOUNT_MOUNT_NONE,
+            gMountOperation,
+            nullptr,
+            mount_finish_callback,
+            con);
     }
-
-    auto gMountOperation = gtk_mount_operation_new ((GtkWindow*) main_win);
-
-    g_volume_mount (dev_con->priv->gVolume,
-        G_MOUNT_MOUNT_NONE,
-        gMountOperation,
-        nullptr,
-        mount_finish_callback,
-        con);
-
 }
 
 
@@ -283,6 +289,20 @@ static void dev_open (GnomeCmdCon *con)
 }
 
 
+static void show_message_dialog_volume_unmounted()
+{
+    DEBUG('m', "unmount_callback: succeeded\n");
+    GtkWidget *msgbox;
+    msgbox = gtk_message_dialog_new (*main_win,
+                                     GTK_DIALOG_MODAL,
+                                     GTK_MESSAGE_INFO,
+                                     GTK_BUTTONS_OK,
+                                     _("Volume successfully unmounted"));
+    gtk_dialog_run (GTK_DIALOG (msgbox));
+    gtk_widget_destroy (msgbox);
+}
+
+
 static void unmount_callback(GObject *gMnt, GAsyncResult *result, gpointer user_data)
 {
     GnomeCmdCon *con = GNOME_CMD_CON (user_data);
@@ -310,16 +330,7 @@ static void unmount_callback(GObject *gMnt, GAsyncResult *result, gpointer user_
 
     con->state = GnomeCmdCon::STATE_CLOSED;
 
-    DEBUG('m', "unmount_callback: succeeded\n");
-
-    msgbox = gtk_message_dialog_new (*main_win,
-                                     GTK_DIALOG_MODAL,
-                                     GTK_MESSAGE_INFO,
-                                     GTK_BUTTONS_OK,
-                                     _("Volume successfully unmounted"));
-
-    gtk_dialog_run (GTK_DIALOG (msgbox));
-    gtk_widget_destroy (msgbox);
+    show_message_dialog_volume_unmounted();
 }
 
 
@@ -365,7 +376,11 @@ static gboolean dev_close (GnomeCmdCon *con)
             g_free (cmd);
 
             if (ret == 0)
+            {
                 con->state = GnomeCmdCon::STATE_CLOSED;
+
+                show_message_dialog_volume_unmounted();
+            }
         }
     }
 
@@ -394,17 +409,25 @@ static GFile *dev_create_gfile (GnomeCmdCon *con, GnomeCmdPath *gnomeCmdPath)
     GFile *newGFile = nullptr;
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
 
-    g_return_val_if_fail (dev_con->priv->gMount != nullptr, nullptr);
-
-    if (gnomeCmdPath)
+    if (dev_con->priv->gMount != nullptr)
     {
-        auto gMountGFile = g_mount_get_default_location (dev_con->priv->gMount);
-        newGFile = g_file_get_child (gMountGFile, gnomeCmdPath->get_path());
-        g_object_unref(gMountGFile);
+        if (gnomeCmdPath)
+        {
+            auto gMountGFile = g_mount_get_default_location (dev_con->priv->gMount);
+            newGFile = g_file_resolve_relative_path(gMountGFile, gnomeCmdPath->get_path());
+            g_object_unref(gMountGFile);
+        }
+        else
+        {
+            newGFile = g_mount_get_default_location (dev_con->priv->gMount);
+        }
     }
     else
     {
-        newGFile = g_mount_get_default_location (dev_con->priv->gMount);
+        if (gnomeCmdPath != nullptr)
+        {
+            newGFile = g_file_new_for_path(gnomeCmdPath->get_path());
+        }
     }
     return newGFile;
 }
@@ -560,7 +583,7 @@ void gnome_cmd_con_device_set_device_fn (GnomeCmdConDevice *dev, const gchar *de
 
     g_free (dev->priv->device_fn);
 
-    dev->priv->device_fn = g_strdup (device_fn);
+    dev->priv->device_fn = g_strdup (device_fn ? device_fn : "");
 }
 
 
@@ -690,7 +713,7 @@ const gchar *gnome_cmd_con_device_get_device_fn (GnomeCmdConDevice *dev)
     g_return_val_if_fail (dev != nullptr, nullptr);
     g_return_val_if_fail (dev->priv != nullptr, nullptr);
 
-    return dev->priv->device_fn;
+    return dev->priv->device_fn != nullptr ? dev->priv->device_fn : "";
 }
 
 
