@@ -2,7 +2,7 @@
  * @file gnome-cmd-xfer-progress-win.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2020 Uwe Scholz\n
+ * @copyright (C) 2013-2022 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,10 +53,10 @@ GtkWidget *gnome_cmd_xfer_progress_win_new (guint no_of_files=0);
 GtkType gnome_cmd_xfer_progress_win_get_type ();
 
 void gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *win,
-                                                     GnomeVFSFileSize file_bytes_copied,
-                                                     GnomeVFSFileSize file_size,
-                                                     GnomeVFSFileSize bytes_copied,
-                                                     GnomeVFSFileSize bytes_total);
+                                                     guint64 file_bytes_copied,
+                                                     guint64 file_size,
+                                                     guint64 bytes_copied,
+                                                     guint64 bytes_total);
 
 void gnome_cmd_xfer_progress_win_set_msg (GnomeCmdXferProgressWin *win, const gchar *string);
 
