@@ -2,7 +2,7 @@
  * @file imageloader.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2020 Uwe Scholz\n
+ * @copyright (C) 2013-2022 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -85,7 +85,7 @@ inline GdkPixbuf *IMAGE_get_pixbuf (Pixmap pixmap_id)
     return pixmap ? pixmap->pixbuf : NULL;
 }
 
-gboolean IMAGE_get_pixmap_and_mask (GnomeVFSFileType type,
+gboolean IMAGE_get_pixmap_and_mask (guint32 type,
                                     const gchar *mime_type,
                                     gboolean symlink,
                                     GdkPixmap **pixmap,
@@ -95,4 +95,6 @@ void IMAGE_clear_mime_cache ();
 
 void register_gnome_commander_stock_icons (void);
 
-char* register_application_stock_icon(const char* openWithDefaultLabel, const char* defaultAppIconPath);
\ No newline at end of file
+const gchar* get_default_application_icon_path(GAppInfo* appInfo);
+
+char* register_application_stock_icon(const char* openWithDefaultLabel, const char* defaultAppIconPath);
