@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2020 Uwe Scholz\n
+ * @copyright (C) 2013-2022 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,29 +53,6 @@
 using namespace std;
 
 
-struct _ViewerFileOps
-{
-    // File handling (based on 'Midnight Commander'-'s view.c)
-    char *filename;        // Name of the file
-    unsigned char *data;    // Memory area for the file to be viewed
-    int file;        // File descriptor (for mmap and munmap)
-    int mmapping;        // Did we use mmap on the file?
-
-    // Growing buffers information
-    int growing_buffer;    // Use the growing buffers?
-    char **block_ptr;    // Pointer to the block pointers
-    int   blocks;        // The number of blocks in *block_ptr
-    struct stat s;        // stat for file
-
-    offset_type last;           // Last byte shown
-    offset_type last_byte;      // Last byte of file
-    offset_type first;        // First byte in file
-    offset_type bottom_first;    // First byte shown when very last page is displayed
-                    // For the case of WINCH we should reset it to -1
-    offset_type bytes_read;     // How much of file is read
-};
-
-
 ViewerFileOps *gv_fileops_new()
 {
     ViewerFileOps *fops = g_new0 (ViewerFileOps, 1);
